#!/usr/bin/env python
#    Copyright 2007 Chris Radek
#    Derived from a work by John Kasunich and Jeff Epler
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from vismach import *
import hal
import math
import sys

# give endpoint Z values and radius
# resulting cylinder is on the Z axis
#class HalToolCylinder(CylinderZ):
#    def __init__(self, comp, *args):
#    CylinderZ.__init__(self, *args)
#    self.comp = comp

 #   def coords(self):
  #  return -self.comp.tool_length, 20, 0, 20

c = hal.component("4axisgui")
c.newpin("jx", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("jy", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("jz", hal.HAL_FLOAT, hal.HAL_IN)
# rotary table-a axis
c.newpin("ja", hal.HAL_FLOAT, hal.HAL_IN)
#c.newpin("jb", hal.HAL_FLOAT, hal.HAL_IN)
#c.newpin("jc", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("tool-length", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("work_diameter", hal.HAL_FLOAT, hal.HAL_IN)
c.ready()

# give endpoint Z values and radii
# resulting cylinder is on the Z axis
class HalWorkCylinder(CylinderX):
    def __init__(self, comp, *args):
        CylinderX.__init__(self, *args)
        self.comp = c

    def coords(self):
        r = 6 # default if hal pin not set
        if (c.work_diameter > 0): r = c.work_diameter/2
        return -200, r, 0, r




pivot_len=100
tool_radius=25

for setting in sys.argv[1:]: exec (setting)

tooltip = Capture()

tool = Collection([
       tooltip,
		# Position + size of tool 	
		# Z-start  radius-start Z-end radius-end
       CylinderZ(0,0.2,24,12),
       CylinderZ(24,12,150,12)
       ])
#tool = Translate([tool],0,0,-20)
tool = Color([1,0,0,0], [tool] )
tool = HalTranslate([tool],c,"tool-length",0,0,-1)

work = Capture()
# Box Z-Achse 
# definition  X-start, Y-start, z-start, X-end, y-end, z-end 
ram = Collection([tool,
                  Box(-50,-50,150, 50,50,700,)
                  ])

# move ram Z-axis to zeropoint
#ram = Translate([ram], 0,0,0)

# definition joint number
ram = HalTranslate([ram],c,"jz",0,0,1)


#ram = Collection([ram,
 #                 Box(-50,50,350, 50,100,550)
 #                 ])
    
ram = HalTranslate([ram],c,"jx",1,0,0)

# box ram  middle left right 
# definition  X-start, Y-start, z-start, X-end, y-end, z-end 
ram = Collection([ram,
                  Box(-100,50,450,	 1200,150,550),
                  Box(-200,50,-450, -100,150,550),
                  Box(1100,50,-450, 1200,150,550)
                  ])

ram = HalTranslate([ram],c,"jy",0,1,0)

# left and right foot
ram = Collection([ram,
                   Box(-200,50,-550,  -100, 1500,-450),
                   Box(1100,50,-550, 1200,1500,-450)
                   ])

# A-axis
atable = Collection([
         work,
         HalWorkCylinder(c),
		# Position + size A-axis chuck frame	
		# X-start  radius-start X-end radius-end
         CylinderX(0, 100, 50, 100),
         # centercross
         Color([1,1,1,0], [CylinderZ(-100,2,100,2)]),
         Color([1,1,1,0], [CylinderY(-100,2,100,2)]),
         # zeromark on top 
         Color([1,1,1,0], [Box( -4, -10, 90, 0, 10, 100)])
         ])

atable = HalRotate([atable],c,"ja",1,-1,0,0)
# A-axis move to X, Y, Z centerpoint
atable = Translate([atable],600,200,-200)

atable = Color([1,0,1,0], [atable] )
arotary = Collection([
          atable,
          # # rotary table base - part under table
          Color([0.3,0.5,1,0], [Box(-50,-50, -30, 50, 50, -18)])
          ])
#arotary = HalTranslate([arotary],a,"x-offset",0,1,0)
#arotary = HalTranslate([arotary],a,"z-offset",0,0,-1)

# Halterung A-Achse
#yoke = Collection([
       # trunnion plate
#       Color([1,0.5,0,0], [Box(-65,-40,-35,65,40,-25)]),
       # side plate left
#       Color([1,0.5,0,0], [Box(-65,-40,-35,-55,40,0)]),
       # side plate right
#       Color([1,0.5,0,0], [Box(55,-40,-35,65,40,0)])
#       ])

# table
table = Collection([
	work,
	Box(0,0,-400, 1000,1300,-450)
        ])

model = Collection([ram, table, atable])

main(model, tooltip, work, lon=25, lat=-60, size=1500)
